You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [3/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresPermissions.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresPermissions.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Annotations used to restrict which classes, instances, or methods may be accessed or invoked depending on the
- * caller's access abilities or authentication state.
- */
-package org.apache.ki.authz.annotation;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Annotations used to restrict which classes, instances, or methods may be accessed or invoked depending on the
+ * caller's access abilities or authentication state.
+ */
+package org.apache.shiro.authz.annotation;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AnnotationsAuthorizingMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AnnotationsAuthorizingMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AnnotationsAuthorizingMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AnnotationsAuthorizingMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.ki.aop.MethodInvocation;
-import org.apache.ki.authz.AuthorizationException;
+import org.apache.shiro.aop.MethodInvocation;
+import org.apache.shiro.authz.AuthorizationException;
 
 /**
  * An <tt>AnnotationsAuthorizingMethodInterceptor</tt> is a MethodInterceptor that asserts a given method is authorized
@@ -87,9 +87,9 @@
     /**
      * Iterates over the internal {@link #getMethodInterceptors() methodInterceptors} collection, and for each one,
      * ensures that if the interceptor
-     * {@link AuthorizingAnnotationMethodInterceptor#supports(org.apache.ki.aop.MethodInvocation) supports}
+     * {@link AuthorizingAnnotationMethodInterceptor#supports(org.apache.shiro.aop.MethodInvocation) supports}
      * the invocation, that the interceptor
-     * {@link AuthorizingAnnotationMethodInterceptor#assertAuthorized(org.apache.ki.aop.MethodInvocation) asserts}
+     * {@link AuthorizingAnnotationMethodInterceptor#assertAuthorized(org.apache.shiro.aop.MethodInvocation) asserts}
      * that the invocation is authorized to proceed.
      */
     protected void assertAuthorized(MethodInvocation methodInvocation) throws AuthorizationException {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
-import org.apache.ki.authz.annotation.RequiresRoles;
+import org.apache.shiro.authz.annotation.RequiresRoles;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Contains AOP implementation support classes specifically used for authorization operations, particularly supporting
- * AOP Method Interceptors and JSR-175 metadata Annotations.
- */
-package org.apache.ki.authz.aop;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Contains AOP implementation support classes specifically used for authorization operations, particularly supporting
+ * AOP Method Interceptors and JSR-175 metadata Annotations.
+ */
+package org.apache.shiro.authz.aop;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/AllPermission.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/AllPermission.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
 import java.io.Serializable;
 
-import org.apache.ki.authz.Permission;
+import org.apache.shiro.authz.Permission;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/DomainPermission.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/DomainPermission.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/DomainPermission.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/DomainPermission.java Thu Jun 18 03:13:34 2009
@@ -1,6 +1,6 @@
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.util.StringUtils;
 
 /**
  * Provides a base Permission class from which type-safe/domain-specific subclasses may extend.  Can be used

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/InvalidPermissionStringException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/InvalidPermissionStringException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/InvalidPermissionStringException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/InvalidPermissionStringException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -28,7 +28,8 @@
  * @author Jeremy Haile
  * @since 0.9
  */
-public class InvalidPermissionStringException extends KiException {
+public class InvalidPermissionStringException extends ShiroException
+{
 
     private String permissionString;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolver.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolver.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermissionResolver.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermissionResolver.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
-import org.apache.ki.authz.Permission;
+import org.apache.shiro.authz.Permission;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManagerAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManagerAware.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 /**
  * Interface implemented by components that utilize a CacheManager and wish that CacheManager to be supplied if

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/DefaultCacheManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/DefaultCacheManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCacheManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCacheManager.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 /**
  * A {@link CacheManager} that returns {@link HashtableCache} caches.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/MapCache.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/MapCache.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/MapCache.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/MapCache.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 import java.util.Collection;
 import java.util.Collections;
@@ -24,7 +24,7 @@
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.ki.util.Destroyable;
+import org.apache.shiro.util.Destroyable;
 
 /**
  * A <code>MapCache</code> is a {@link Cache Cache} implementation that uses a backing {@link Map} instance to store

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/SoftHashMapCache.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/SoftHashMapCache.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/SoftHashMapCache.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/SoftHashMapCache.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
-import org.apache.ki.util.SoftHashMap;
+import org.apache.shiro.util.SoftHashMap;
 
 /**
  * A MapCache that uses a {@link SoftHashMap SoftHashMap} as its backing map.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/package-info.java Thu Jun 18 03:13:34 2009
@@ -19,4 +19,4 @@
 /**
  * Caching support used to enhance performance for any security operation.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Base64.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Base64.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.codec;
+package org.apache.shiro.codec;
+
+import org.apache.shiro.ShiroException;
 
-import org.apache.ki.KiException;
 
 /**
  * Root exception related to issues during encoding or decoding.
@@ -26,7 +27,8 @@
  * @author Les Hazlewood
  * @since 0.9
  */
-public class CodecException extends KiException {
+public class CodecException extends ShiroException
+{
 
     /**
      * Creates a new <code>CodecException</code>.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecSupport.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecSupport.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/IniConfiguration.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/IniConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 import java.io.InputStream;
 import java.io.Reader;
@@ -30,15 +30,15 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
-import org.apache.ki.io.IniResource;
-import org.apache.ki.io.ResourceUtils;
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.mgt.RealmSecurityManager;
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.realm.RealmFactory;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.ShiroException;
+import org.apache.shiro.io.IniResource;
+import org.apache.shiro.io.ResourceUtils;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.mgt.RealmSecurityManager;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.realm.RealmFactory;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
@@ -54,7 +54,7 @@
 
     private static final Logger log = LoggerFactory.getLogger(IniConfiguration.class);
 
-    public static final String DEFAULT_INI_RESOURCE_PATH = "classpath:ki.ini";
+    public static final String DEFAULT_INI_RESOURCE_PATH = "classpath:shiro.ini";
 
     public static final String MAIN = "main";
 
@@ -88,16 +88,17 @@
         this.configUrl = configUrl;
     }
 
-    public void init() throws KiException {
+    public void init() throws ShiroException
+    {
 
         if (configUrl != null) {
             if (ResourceUtils.resourceExists(configUrl)) {
                 load(configUrl);
             } else {
                 if (ignoreResourceNotFound) {
-                    log.debug("Ki resource [{}] not found.  Ignoring since 'ignoreResourceNotFound' is true.", configUrl);
+                    log.debug("Shiro resource [{}] not found.  Ignoring since 'ignoreResourceNotFound' is true.", configUrl);
                 } else {
-                    throw new ConfigurationException("Ki resource [" + configUrl + "] specified as a 'configUrl' " +
+                    throw new ConfigurationException("Shiro resource [" + configUrl + "] specified as a 'configUrl' " +
                             "cannot be found.  If you want to fall back on default configuration specified " +
                             "via the 'config' parameter, then set 'ignoreResourceNotFound' to true.");
                 }
@@ -171,7 +172,7 @@
         afterSecurityManagerSet(sections);
     }
 
-    protected org.apache.ki.mgt.SecurityManager createDefaultSecurityManager() {
+    protected org.apache.shiro.mgt.SecurityManager createDefaultSecurityManager() {
         return newSecurityManagerInstance();
     }
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ReflectionBuilder.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ReflectionBuilder.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ResourceConfiguration.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ResourceConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 import java.io.InputStream;
 import java.io.Serializable;
 
-import org.apache.ki.mgt.SecurityManager;
+import org.apache.shiro.mgt.SecurityManager;
 
 
 /**
@@ -31,7 +31,7 @@
  */
 public abstract class ResourceConfiguration implements Configuration, Serializable {
 
-    protected transient org.apache.ki.mgt.SecurityManager securityManager;
+    protected transient org.apache.shiro.mgt.SecurityManager securityManager;
 
     public ResourceConfiguration() {
     }

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/TextConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/TextConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/TextConfiguration.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/TextConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 import java.io.Reader;
 import java.io.StringReader;
@@ -25,10 +25,10 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
-import org.apache.ki.io.ResourceException;
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.util.Initializable;
+import org.apache.shiro.ShiroException;
+import org.apache.shiro.io.ResourceException;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.util.Initializable;
 
 
 /**
@@ -74,7 +74,8 @@
         }
     }
 
-    public void init() throws KiException {
+    public void init() throws ShiroException
+    {
         SecurityManager securityManager = getSecurityManager();
         if (securityManager == null) {
             String config = getConfig();

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/UnresolveableReferenceException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/UnresolveableReferenceException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/UnresolveableReferenceException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/UnresolveableReferenceException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 /**
  * Exception thrown when a reference to an object is made, but that object cannot be found.  This is most likely

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresPermissions.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresPermissions.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.annotation;
+package org.apache.shiro.authz.annotation;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -27,7 +27,7 @@
  * <p>
  * Requires the current executor's Subject to imply a particular permission in
  * order to execute the annotated method.  If the executor's associated
  * {@link org.apache.ki.subject.Subject Subject} determines that the
  * executor does not imply the specified permission, the method will not be executed.
  * </p>
  *
@@ -38,11 +38,11 @@
  * <p/>
  * indicates the current user must be able to both <tt>read</tt> and <tt>write</tt>
  * to the file <tt>aFile.txt</tt> in order for the <tt>someMethod()</tt> to execute, otherwise
  * an {@link org.apache.ki.authz.AuthorizationException AuthorizationException} will be thrown.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.subject.Subject#checkPermission
+ * @see org.apache.shiro.subject.Subject#checkPermission
  * @since 0.1
  */
 @Target(ElementType.METHOD)
@@ -50,7 +50,7 @@
 public @interface RequiresPermissions {
 
     /**
-     * The permission string which will be passed to {@link org.apache.ki.subject.Subject#isPermitted(String)}
+     * The permission string which will be passed to {@link org.apache.shiro.subject.Subject#isPermitted(String)}
      * to determine if the user is allowed to invoke the code protected by this annotation.
      */
     String value();
@@ -27,7 +27,7 @@
  * Requires the current executor's Subject to imply a particular permission in
  * order to execute the annotated method.  If the executor's associated
- * {@link org.apache.ki.subject.Subject Subject} determines that the
+ * {@link org.apache.shiro.subject.Subject Subject} determines that the
  * executor does not imply the specified permission, the method will not be executed.
  * </p>
@@ -38,11 +38,11 @@
  * indicates the current user must be able to both <tt>read</tt> and <tt>write</tt>
  * to the file <tt>aFile.txt</tt> in order for the <tt>someMethod()</tt> to execute, otherwise
- * an {@link org.apache.ki.authz.AuthorizationException AuthorizationException} will be thrown.
+ * an {@link org.apache.shiro.authz.AuthorizationException AuthorizationException} will be thrown.
  *
  * @author Jeremy Haile

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresRoles.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresRoles.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresRoles.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresRoles.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.annotation;
+package org.apache.shiro.authz.annotation;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -24,9 +24,9 @@
 import java.lang.annotation.Target;
 
 /**
  * Requires the currently executing {@link org.apache.ki.subject.Subject Subject} to have one or more specified roles
  * in order to execute the annotated method. If they do not have the role(s), the method will not be executed and
  * an {@link org.apache.ki.authz.AuthorizationException AuthorizationException} is thrown.
  * <p/>
  * For example,
  * <p/>
@@ -49,7 +49,7 @@
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.subject.Subject#hasRole(String)
+ * @see org.apache.shiro.subject.Subject#hasRole(String)
  * @since 0.1
  */
 @Target(ElementType.METHOD)
@@ -24,9 +24,9 @@
 
 /**
- * Requires the currently executing {@link org.apache.ki.subject.Subject Subject} to have one or more specified roles
+ * Requires the currently executing {@link org.apache.shiro.subject.Subject Subject} to have one or more specified roles
  * in order to execute the annotated method. If they do not have the role(s), the method will not be executed and
@@ -24,9 +24,9 @@
  * in order to execute the annotated method. If they do not have the role(s), the method will not be executed and
- * an {@link org.apache.ki.authz.AuthorizationException AuthorizationException} is thrown.
+ * an {@link org.apache.shiro.authz.AuthorizationException AuthorizationException} is thrown.
  * <p/>
  * For example,

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresUser.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresUser.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresUser.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresUser.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.annotation;
+package org.apache.shiro.authz.annotation;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -28,7 +28,7 @@
  * accessed or invoked.  This is <em>less</em> restrictive than the {@link RequiresAuthentication RequiresAuthentication}
  * annotation.
  * <p/>
  * Ki defines a &quot;user&quot; as a Subject that is either
  * &quot;remembered&quot; <b><em>or</em></b> authenticated:
  * <ul>
  * <li>An <b>authenticated</b> user is a Subject that has successfully logged in (proven their identity)
@@ -37,7 +37,7 @@
  * during their current session, and asked the system to remember them.</li>
  * </ul>
  * <p/>
  * See the {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
  * explaination of why these two states are considered different.
  *
  * @see RequiresAuthentication
@@ -28,7 +28,7 @@
  * annotation.
  * <p/>
- * Ki defines a &quot;user&quot; as a Subject that is either
+ * Shiro defines a &quot;user&quot; as a Subject that is either
  * &quot;remembered&quot; <b><em>or</em></b> authenticated:
  * <ul>
@@ -37,7 +37,7 @@
  * </ul>
  * <p/>
- * See the {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
+ * See the {@link org.apache.shiro.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
  * explaination of why these two states are considered different.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 
-import org.apache.ki.authz.UnauthenticatedException;
-import org.apache.ki.authz.annotation.RequiresAuthentication;
+import org.apache.shiro.authz.UnauthenticatedException;
+import org.apache.shiro.authz.annotation.RequiresAuthentication;
 
 
 /**
@@ -35,7 +35,7 @@
 
     /**
      * Default no-argument constructor that ensures this handler to process
-     * {@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthentication} annotations.
+     * {@link org.apache.shiro.authz.annotation.RequiresAuthentication RequiresAuthentication} annotations.
      */
     public AuthenticatedAnnotationHandler() {
         super(RequiresAuthentication.class);
@@ -43,10 +43,10 @@
 
     /**
      * Ensures that the calling <code>Subject</code> is authenticated, and if not, throws an
      * {@link org.apache.ki.authz.UnauthenticatedException UnauthenticatedException} indicating the method is not allowed to be executed.
      *
      * @param a the annotation to inspect
      * @throws org.apache.ki.authz.UnauthenticatedException if the calling <code>Subject</code> has not yet
      * authenticated.
      */
     public void assertAuthorized(Annotation a) throws UnauthenticatedException {
@@ -43,10 +43,10 @@
     /**
      * Ensures that the calling <code>Subject</code> is authenticated, and if not, throws an
-     * {@link org.apache.ki.authz.UnauthenticatedException UnauthenticatedException} indicating the method is not allowed to be executed.
+     * {@link org.apache.shiro.authz.UnauthenticatedException UnauthenticatedException} indicating the method is not allowed to be executed.
      *
      * @param a the annotation to inspect
@@ -43,10 +43,10 @@
      *
      * @param a the annotation to inspect
-     * @throws org.apache.ki.authz.UnauthenticatedException if the calling <code>Subject</code> has not yet
+     * @throws org.apache.shiro.authz.UnauthenticatedException if the calling <code>Subject</code> has not yet
      * authenticated.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthenticatedAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthenticated} annotation
  * is declared, and if so, ensures the calling
  * <code>Subject</code>.{@link org.apache.ki.subject.Subject#isAuthenticated() isAuthenticated()} before invoking
  * the method.
  *
  * @since 0.9.0
@@ -31,7 +31,7 @@
 
     /**
      * Default no-argument constructor that ensures this interceptor looks for
      * {@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthentication} annotations in a method
      * declaration.
      */
     public AuthenticatedAnnotationMethodInterceptor() {
@@ -16,12 +16,12 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthenticated} annotation
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresAuthentication RequiresAuthenticated} annotation
  * is declared, and if so, ensures the calling
@@ -16,12 +16,12 @@
  * is declared, and if so, ensures the calling
- * <code>Subject</code>.{@link org.apache.ki.subject.Subject#isAuthenticated() isAuthenticated()} before invoking
+ * <code>Subject</code>.{@link org.apache.shiro.subject.Subject#isAuthenticated() isAuthenticated()} before invoking
  * the method.
  *
@@ -31,7 +31,7 @@
     /**
      * Default no-argument constructor that ensures this interceptor looks for
-     * {@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthentication} annotations in a method
+     * {@link org.apache.shiro.authz.annotation.RequiresAuthentication RequiresAuthentication} annotations in a method
      * declaration.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 
-import org.apache.ki.aop.AnnotationHandler;
-import org.apache.ki.authz.AuthorizationException;
+import org.apache.shiro.aop.AnnotationHandler;
+import org.apache.shiro.authz.AuthorizationException;
 
 /**
  * An AnnotationHandler that executes authorization (access control) behavior based on directive(s) found in a
@@ -50,7 +50,7 @@
      * and perform a corresponding authorization check based.
      *
      * @param a the <code>Annotation</code> to check for performing an authorization check.
      * @throws org.apache.ki.authz.AuthorizationException if the class/instance/method is not allowed to proceed/execute.
      */
     public abstract void assertAuthorized(Annotation a) throws AuthorizationException;
 }
@@ -50,7 +50,7 @@
      *
      * @param a the <code>Annotation</code> to check for performing an authorization check.
-     * @throws org.apache.ki.authz.AuthorizationException if the class/instance/method is not allowed to proceed/execute.
+     * @throws org.apache.shiro.authz.AuthorizationException if the class/instance/method is not allowed to proceed/execute.
      */
     public abstract void assertAuthorized(Annotation a) throws AuthorizationException;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
-import org.apache.ki.aop.AnnotationMethodInterceptor;
-import org.apache.ki.aop.MethodInvocation;
-import org.apache.ki.authz.AuthorizationException;
+import org.apache.shiro.aop.AnnotationMethodInterceptor;
+import org.apache.shiro.aop.MethodInvocation;
+import org.apache.shiro.authz.AuthorizationException;
 
 
 /**
@@ -45,11 +45,11 @@
 
     /**
      * Ensures the <code>methodInvocation</code> is allowed to execute first before proceeding by calling the
-     * {@link #assertAuthorized(org.apache.ki.aop.MethodInvocation) assertAuthorized} method first.
+     * {@link #assertAuthorized(org.apache.shiro.aop.MethodInvocation) assertAuthorized} method first.
      *
      * @param methodInvocation the method invocation to check for authorization prior to allowing it to proceed/execute.
      * @return the return value from the method invocation (the value of {@link org.apache.ki.aop.MethodInvocation#proceed() MethodInvocation.proceed()}).
      * @throws org.apache.ki.authz.AuthorizationException if the <code>MethodInvocation</code> is not allowed to proceed.
      * @throws Throwable if any other error occurs.
      */
     public Object invoke(MethodInvocation methodInvocation) throws Throwable {
@@ -45,11 +45,11 @@
      *
      * @param methodInvocation the method invocation to check for authorization prior to allowing it to proceed/execute.
-     * @return the return value from the method invocation (the value of {@link org.apache.ki.aop.MethodInvocation#proceed() MethodInvocation.proceed()}).
-     * @throws org.apache.ki.authz.AuthorizationException if the <code>MethodInvocation</code> is not allowed to proceed.
+     * @return the return value from the method invocation (the value of {@link org.apache.shiro.aop.MethodInvocation#proceed() MethodInvocation.proceed()}).
+     * @throws org.apache.shiro.authz.AuthorizationException if the <code>MethodInvocation</code> is not allowed to proceed.
      * @throws Throwable if any other error occurs.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/AuthorizingMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
-import org.apache.ki.aop.MethodInterceptorSupport;
-import org.apache.ki.aop.MethodInvocation;
-import org.apache.ki.authz.AuthorizationException;
+import org.apache.shiro.aop.MethodInterceptorSupport;
+import org.apache.shiro.aop.MethodInvocation;
+import org.apache.shiro.authz.AuthorizationException;
 
 /**
  * Basic abstract class to support intercepting methods that perform authorization (access control) checks.
@@ -31,9 +31,9 @@
 public abstract class AuthorizingMethodInterceptor extends MethodInterceptorSupport {
 
     /**
      * Invokes the specified method (<code>methodInvocation.{@link org.apache.ki.aop.MethodInvocation#proceed proceed}()</code>
      * if authorization is allowed by first
-     * calling {@link #assertAuthorized(org.apache.ki.aop.MethodInvocation) assertAuthorized}.
+     * calling {@link #assertAuthorized(org.apache.shiro.aop.MethodInvocation) assertAuthorized}.
      */
     public Object invoke(MethodInvocation methodInvocation) throws Throwable {
         assertAuthorized(methodInvocation);
@@ -31,9 +31,9 @@
 
     /**
-     * Invokes the specified method (<code>methodInvocation.{@link org.apache.ki.aop.MethodInvocation#proceed proceed}()</code>
+     * Invokes the specified method (<code>methodInvocation.{@link org.apache.shiro.aop.MethodInvocation#proceed proceed}()</code>
      * if authorization is allowed by first

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,21 +16,21 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.UnauthenticatedException;
-import org.apache.ki.authz.annotation.RequiresGuest;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.UnauthenticatedException;
+import org.apache.shiro.authz.annotation.RequiresGuest;
 
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
  * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before invoking the method.
  * <p>
  * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
  *
  * @author Les Hazlewood
  * @since 0.9.0
@@ -40,7 +40,7 @@
     /**
      * Default no-argument constructor that ensures this interceptor looks for
      *
      * {@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
      * declaration.
      */
     public GuestAnnotationHandler() {
@@ -49,12 +49,12 @@
 
     /**
      * Ensures that the calling <code>Subject</code> is NOT a <em>user</em>, that is, they do not
      * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before continuing.  If they are
      * a user ({@link org.apache.ki.subject.Subject#getPrincipal() Subject.getPrincipal()} != null), an
      * <code>AuthorizingException</code> will be thrown indicating that execution is not allowed to continue.
      *
      * @param a the annotation to check for one or more roles
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if the calling <code>Subject</code> is not a &quot;guest&quot;.
      */
     public void assertAuthorized(Annotation a) throws AuthorizationException {
@@ -16,21 +16,21 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotation
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresGuest RequiresGuest} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
@@ -16,21 +16,21 @@
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
- * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before invoking the method.
+ * have an {@link org.apache.shiro.subject.Subject#getPrincipal() identity} before invoking the method.
  * <p>
@@ -16,21 +16,21 @@
  * <p>
- * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
+ * This annotation essentially ensures that <code>subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
  *
  * @author Les Hazlewood
@@ -40,7 +40,7 @@
      * Default no-argument constructor that ensures this interceptor looks for
      *
-     * {@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
+     * {@link org.apache.shiro.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
      * declaration.
      */
@@ -49,12 +49,12 @@
     /**
      * Ensures that the calling <code>Subject</code> is NOT a <em>user</em>, that is, they do not
-     * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before continuing.  If they are
-     * a user ({@link org.apache.ki.subject.Subject#getPrincipal() Subject.getPrincipal()} != null), an
+     * have an {@link org.apache.shiro.subject.Subject#getPrincipal() identity} before continuing.  If they are
+     * a user ({@link org.apache.shiro.subject.Subject#getPrincipal() Subject.getPrincipal()} != null), an
      * <code>AuthorizingException</code> will be thrown indicating that execution is not allowed to continue.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/GuestAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
  * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before invoking the method.
  * <p>
  * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
  *
  * @author Les Hazlewood
  * @since 0.9.0
@@ -32,7 +32,7 @@
 
     /**
      * Default no-argument constructor that ensures this interceptor looks for
      * {@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
      * declaration.
      */
     public GuestAnnotationMethodInterceptor() {
@@ -16,14 +16,14 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotation
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresGuest RequiresGuest} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
@@ -16,14 +16,14 @@
  * is declared, and if so, ensures the calling <code>Subject</code> does <em>not</em>
- * have an {@link org.apache.ki.subject.Subject#getPrincipal() identity} before invoking the method.
+ * have an {@link org.apache.shiro.subject.Subject#getPrincipal() identity} before invoking the method.
  * <p>
@@ -16,14 +16,14 @@
  * <p>
- * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
+ * This annotation essentially ensures that <code>subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
  *
  * @author Les Hazlewood
@@ -32,7 +32,7 @@
     /**
      * Default no-argument constructor that ensures this interceptor looks for
-     * {@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
+     * {@link org.apache.shiro.authz.annotation.RequiresGuest RequiresGuest} annotations in a method
      * declaration.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 import java.util.Set;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.UnauthorizedException;
-import org.apache.ki.authz.annotation.RequiresPermissions;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.PermissionUtils;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.UnauthorizedException;
+import org.apache.shiro.authz.annotation.RequiresPermissions;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.PermissionUtils;
 
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotation is
  * declared, and if so, performs a permission check to see if the calling <code>Subject</code> is allowed continued
  * access.
  *
@@ -40,7 +40,7 @@
 
     /**
      * Default no-argument constructor that ensures this handler looks for
-     * {@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotations.
+     * {@link org.apache.shiro.authz.annotation.RequiresPermissions RequiresPermissions} annotations.
      */
     public PermissionAnnotationHandler() {
         super(RequiresPermissions.class);
@@ -62,7 +62,7 @@
      * <code>AuthorizingException</code> indicating access is denied.
      *
      * @param a the RequiresPermission annotation being inspected to check for one or more permissions
      * @throws org.apache.ki.authz.AuthorizationException if the calling <code>Subject</code> does not have the permission(s) necessary to
      * continue access or execution.
      */
     public void assertAuthorized(Annotation a) throws AuthorizationException {
@@ -16,20 +16,20 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotation is
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresPermissions RequiresPermissions} annotation is
  * declared, and if so, performs a permission check to see if the calling <code>Subject</code> is allowed continued
  * access.
@@ -62,7 +62,7 @@
      *
      * @param a the RequiresPermission annotation being inspected to check for one or more permissions
-     * @throws org.apache.ki.authz.AuthorizationException if the calling <code>Subject</code> does not have the permission(s) necessary to
+     * @throws org.apache.shiro.authz.AuthorizationException if the calling <code>Subject</code> does not have the permission(s) necessary to
      * continue access or execution.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/PermissionAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotation is declared, and if so, performs
  * a permission check to see if the calling <code>Subject</code> is allowed to call the method.
  * @author Les Hazlewood
  * @since 0.9
@@ -33,7 +33,7 @@
 
     /**
      * Default no-argument constructor that ensures this interceptor looks for
      * {@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotations in a method declaration.
      */
     public PermissionAnnotationMethodInterceptor() {
         super( new PermissionAnnotationHandler() );
@@ -16,10 +16,10 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotation is declared, and if so, performs
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresPermissions RequiresPermissions} annotation is declared, and if so, performs
  * a permission check to see if the calling <code>Subject</code> is allowed to call the method.
  * @author Les Hazlewood
@@ -33,7 +33,7 @@
     /**
      * Default no-argument constructor that ensures this interceptor looks for
-     * {@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions} annotations in a method declaration.
+     * {@link org.apache.shiro.authz.annotation.RequiresPermissions RequiresPermissions} annotations in a method declaration.
      */
     public PermissionAnnotationMethodInterceptor() {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationHandler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationHandler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 import java.util.Arrays;
 import java.util.LinkedHashSet;
 import java.util.Set;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.UnauthorizedException;
-import org.apache.ki.authz.annotation.RequiresRoles;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.UnauthorizedException;
+import org.apache.shiro.authz.annotation.RequiresRoles;
 
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresRoles RequiresRoles} annotation is declared, and if so, performs
  * a role check to see if the calling <code>Subject</code> is allowed to proceed.
  *
  * @author Les Hazlewood
@@ -39,7 +39,7 @@
 
     /**
      * Default no-argument constructor that ensures this handler looks for
-     * {@link org.apache.ki.authz.annotation.RequiresRoles RequiresRoles} annotations.
+     * {@link org.apache.shiro.authz.annotation.RequiresRoles RequiresRoles} annotations.
      */
     public RoleAnnotationHandler() {
         super(RequiresRoles.class);
@@ -50,7 +50,7 @@
      * <code>AuthorizingException</code> indicating that access is denied.
      *
      * @param a the RequiresRoles annotation to use to check for one or more roles
      * @throws org.apache.ki.authz.AuthorizationException if the calling <code>Subject</code> does not have the role(s) necessary to
      * proceed.
      */
     public void assertAuthorized(Annotation a) throws AuthorizationException {
@@ -16,20 +16,20 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresRoles RequiresRoles} annotation is declared, and if so, performs
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresRoles RequiresRoles} annotation is declared, and if so, performs
  * a role check to see if the calling <code>Subject</code> is allowed to proceed.
  *
@@ -50,7 +50,7 @@
      *
      * @param a the RequiresRoles annotation to use to check for one or more roles
-     * @throws org.apache.ki.authz.AuthorizationException if the calling <code>Subject</code> does not have the role(s) necessary to
+     * @throws org.apache.shiro.authz.AuthorizationException if the calling <code>Subject</code> does not have the role(s) necessary to
      * proceed.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/RoleAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationHandler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationHandler.java Thu Jun 18 03:13:34 2009
@@ -16,22 +16,22 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 import java.lang.annotation.Annotation;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.UnauthenticatedException;
-import org.apache.ki.authz.annotation.RequiresUser;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.UnauthenticatedException;
+import org.apache.shiro.authz.annotation.RequiresUser;
 
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
  * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
  * me services before allowing access.
  * <p>
  * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
  *
  * @author Les Hazlewood
  * @since 0.9.0
@@ -41,7 +41,7 @@
     /**
      * Default no-argument constructor that ensures this handler looks for
      *
-     * {@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotations.
+     * {@link org.apache.shiro.authz.annotation.RequiresUser RequiresUser} annotations.
      */
     public UserAnnotationHandler() {
         super(RequiresUser.class);
@@ -49,12 +49,12 @@
 
     /**
      * Ensures that the calling <code>Subject</code> is a <em>user</em>, that is, they are <em>either</code>
      * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
      * me services before allowing access, and if not, throws an
      * <code>AuthorizingException</code> indicating access is not allowed.
      *
      * @param a the RequiresUser annotation to check
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *         if the calling <code>Subject</code> is not authenticated or remembered via rememberMe services.
      */
     public void assertAuthorized(Annotation a) throws AuthorizationException {
@@ -16,22 +16,22 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotation
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresUser RequiresUser} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
@@ -16,22 +16,22 @@
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
- * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
+ * {@link org.apache.shiro.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
  * me services before allowing access.
  * <p>
@@ -16,22 +16,22 @@
  * me services before allowing access.
  * <p>
- * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
+ * This annotation essentially ensures that <code>subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
  *
  * @author Les Hazlewood
@@ -49,12 +49,12 @@
     /**
      * Ensures that the calling <code>Subject</code> is a <em>user</em>, that is, they are <em>either</code>
-     * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
+     * {@link org.apache.shiro.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
      * me services before allowing access, and if not, throws an
      * <code>AuthorizingException</code> indicating access is not allowed.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationMethodInterceptor.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/UserAnnotationMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.aop;
+package org.apache.shiro.authz.aop;
 
 /**
  * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
  * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
  * me services before invoking the method.
  * <p>
  * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
  *
  * @author Les Hazlewood
  * @since 0.9.0
@@ -34,7 +34,7 @@
     /**
      * Default no-argument constructor that ensures this interceptor looks for
      *
      * {@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotations in a method
      * declaration.
      */
     public UserAnnotationMethodInterceptor() {
@@ -16,15 +16,15 @@
 
 /**
- * Checks to see if a @{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotation
+ * Checks to see if a @{@link org.apache.shiro.authz.annotation.RequiresUser RequiresUser} annotation
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
@@ -16,15 +16,15 @@
  * is declared, and if so, ensures the calling <code>Subject</code> is <em>either</em>
- * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
+ * {@link org.apache.shiro.subject.Subject#isAuthenticated() authenticated} <b><em>or</em></b> remembered via remember
  * me services before invoking the method.
  * <p>
@@ -16,15 +16,15 @@
  * me services before invoking the method.
  * <p>
- * This annotation essentially ensures that <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
+ * This annotation essentially ensures that <code>subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()} != null</code>.
  *
  * @author Les Hazlewood
@@ -34,7 +34,7 @@
      * Default no-argument constructor that ensures this interceptor looks for
      *
-     * {@link org.apache.ki.authz.annotation.RequiresUser RequiresUser} annotations in a method
+     * {@link org.apache.shiro.authz.annotation.RequiresUser RequiresUser} annotations in a method
      * declaration.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/aop/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/package-info.java Thu Jun 18 03:13:34 2009
@@ -19,20 +19,20 @@
 /**
  * Core interfaces and exceptions supporting Authorization (access control).
  * <p/>
  * Ki abbreviates the word 'AuthoriZation' as <tt>authz</tt> to distinguish it seperately from
  * 'AuthentiCation', abbreviated as <tt>authc</tt>.
  * <p/>
  * This package's primary interface of interest, which is the core of Ki authorization functionality,
  * is the <tt>Authorizer</tt>. This interface handles all aspects of principal-related security and is the
  * facade to all other Ki authorization components.
  * <p/>
  * Ki has the ability to authorize subjects (a.k.a. users) without being intrusive to the application's
  * domain model. Most applications will utilize the concepts of <tt>group</tt>s, <tt>role</tt>s, and
  * <tt>permission</tt>s, but Ki tries to be as non-invasive as possible doesn't require any such
  * interfaces (although a Permission interface is made available for fine-grained access control policies if
  * you want to use Ki's permission support out-of-the-box).
  * <p/>
  * Although it is possible for applications to implement this and other interfaces directly, it is not
  * recommended. Ki already has base implementations which should be suitable for 99% of deployments.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
@@ -19,20 +19,20 @@
  * Core interfaces and exceptions supporting Authorization (access control).
  * <p/>
- * Ki abbreviates the word 'AuthoriZation' as <tt>authz</tt> to distinguish it seperately from
+ * Shiro abbreviates the word 'AuthoriZation' as <tt>authz</tt> to distinguish it seperately from
  * 'AuthentiCation', abbreviated as <tt>authc</tt>.
  * <p/>
@@ -19,20 +19,20 @@
  * 'AuthentiCation', abbreviated as <tt>authc</tt>.
  * <p/>
- * This package's primary interface of interest, which is the core of Ki authorization functionality,
+ * This package's primary interface of interest, which is the core of Shiro authorization functionality,
  * is the <tt>Authorizer</tt>. This interface handles all aspects of principal-related security and is the
@@ -19,20 +19,20 @@
  * is the <tt>Authorizer</tt>. This interface handles all aspects of principal-related security and is the
- * facade to all other Ki authorization components.
+ * facade to all other Shiro authorization components.
  * <p/>
@@ -19,20 +19,20 @@
  * <p/>
- * Ki has the ability to authorize subjects (a.k.a. users) without being intrusive to the application's
+ * Shiro has the ability to authorize subjects (a.k.a. users) without being intrusive to the application's
  * domain model. Most applications will utilize the concepts of <tt>group</tt>s, <tt>role</tt>s, and
@@ -19,20 +19,20 @@
  * domain model. Most applications will utilize the concepts of <tt>group</tt>s, <tt>role</tt>s, and
- * <tt>permission</tt>s, but Ki tries to be as non-invasive as possible doesn't require any such
+ * <tt>permission</tt>s, but Shiro tries to be as non-invasive as possible doesn't require any such
  * interfaces (although a Permission interface is made available for fine-grained access control policies if
@@ -19,20 +19,20 @@
  * interfaces (although a Permission interface is made available for fine-grained access control policies if
- * you want to use Ki's permission support out-of-the-box).
+ * you want to use Shiro's permission support out-of-the-box).
  * <p/>
  * Although it is possible for applications to implement this and other interfaces directly, it is not
@@ -19,20 +19,20 @@
  * <p/>
  * Although it is possible for applications to implement this and other interfaces directly, it is not
- * recommended. Ki already has base implementations which should be suitable for 99% of deployments.
+ * recommended. Shiro already has base implementations which should be suitable for 99% of deployments.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/AllPermission.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/AllPermission.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolver.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolver.java Thu Jun 18 03:13:34 2009
@@ -16,38 +16,38 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
-import org.apache.ki.authz.Permission;
+import org.apache.shiro.authz.Permission;
 
 
 /**
  * <p>A PermisisonResolver resolves a String value and converts it into a
- * {@link org.apache.ki.authz.Permission} instance.
+ * {@link org.apache.shiro.authz.Permission} instance.
  *
  * <p>The default {@link WildcardPermissionResolver} should be
  * suitable for most purposes, which constructs {@link WildcardPermission} objects.
  * However, any resolver may be configured if an application wishes to use different
- * {@link org.apache.ki.authz.Permission} implementations.</p>
+ * {@link org.apache.shiro.authz.Permission} implementations.</p>
  *
  * <p>A <tt>PermissionResolver</tt> is used by many Ki components such as annotations, property file
  * configuration, URL configuration, etc.  It is useful whenever a String representation of a permission is specified
  * and that String needs to be converted to a Permission instance before executing a security check.</p>
  * <p/>
  * Ki chooses to support {@link WildcardPermission Wildcardpermission}s by default in almost all components and
  * we do that in the form of the {@link WildcardPermissionResolver WildcardPermissionResolver}.   One of the nice
  * things about <code>WildcardPermission</code>s being supported by default is that it makes it very easy to
  * store complex permissions in the database - and also makes it very easy to represent permissions in JSP files,
  * annotations, etc., where a simple string representation is useful.
  * <p/>
  * Although this happens to be the Ki default, you are of course free to provide custom
  * String-to-Permission conversion by providing Ki components any instance of this interface.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
  * @see org.apache.ki.mgt.AuthorizingSecurityManager#setPermissionResolver(PermissionResolver) AuthorizingSecurityManager.setPermissionResolver
  * @see org.apache.ki.authz.ModularRealmAuthorizer#setPermissionResolver(PermissionResolver) ModularRealmAuthorizer.setPermissionResolver
  * @see org.apache.ki.realm.AuthorizingRealm#setPermissionResolver(PermissionResolver) AuthorizingRealm.setPermissionResolver
  * @see PermissionResolverAware PermissionResolverAware
  * @since 0.9
  */
@@ -16,38 +16,38 @@
  *
- * <p>A <tt>PermissionResolver</tt> is used by many Ki components such as annotations, property file
+ * <p>A <tt>PermissionResolver</tt> is used by many Shiro components such as annotations, property file
  * configuration, URL configuration, etc.  It is useful whenever a String representation of a permission is specified
  * and that String needs to be converted to a Permission instance before executing a security check.</p>
@@ -16,38 +16,38 @@
  * and that String needs to be converted to a Permission instance before executing a security check.</p>
  * <p/>
- * Ki chooses to support {@link WildcardPermission Wildcardpermission}s by default in almost all components and
+ * Shiro chooses to support {@link WildcardPermission Wildcardpermission}s by default in almost all components and
  * we do that in the form of the {@link WildcardPermissionResolver WildcardPermissionResolver}.   One of the nice
  * things about <code>WildcardPermission</code>s being supported by default is that it makes it very easy to
@@ -16,38 +16,38 @@
  * annotations, etc., where a simple string representation is useful.
  * <p/>
- * Although this happens to be the Ki default, you are of course free to provide custom
- * String-to-Permission conversion by providing Ki components any instance of this interface.
+ * Although this happens to be the Shiro default, you are of course free to provide custom
+ * String-to-Permission conversion by providing Shiro components any instance of this interface.
  *
  * @author Jeremy Haile
@@ -16,38 +16,38 @@
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.mgt.AuthorizingSecurityManager#setPermissionResolver(PermissionResolver) AuthorizingSecurityManager.setPermissionResolver
- * @see org.apache.ki.authz.ModularRealmAuthorizer#setPermissionResolver(PermissionResolver) ModularRealmAuthorizer.setPermissionResolver
- * @see org.apache.ki.realm.AuthorizingRealm#setPermissionResolver(PermissionResolver) AuthorizingRealm.setPermissionResolver
+ * @see org.apache.shiro.mgt.AuthorizingSecurityManager#setPermissionResolver(PermissionResolver) AuthorizingSecurityManager.setPermissionResolver
+ * @see org.apache.shiro.authz.ModularRealmAuthorizer#setPermissionResolver(PermissionResolver) ModularRealmAuthorizer.setPermissionResolver
+ * @see org.apache.shiro.realm.AuthorizingRealm#setPermissionResolver(PermissionResolver) AuthorizingRealm.setPermissionResolver
  * @see PermissionResolverAware PermissionResolverAware
  * @since 0.9

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolverAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolverAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolverAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/PermissionResolverAware.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
 /**
  * Interface implemented by a component that wishes to use any application-configured <tt>PermissionResolver</tt> that
  * might already exist instead of potentially creating one itself.
  *
  * <p>This is mostly implemented by {@link org.apache.ki.authz.Authorizer Authorizer} and
  * {@link org.apache.ki.realm.Realm Realm} implementations since they
  * are the ones performing permission checks and need to know how to resolve Strings into
- * {@link org.apache.ki.authz.Permission Permission} instances.
+ * {@link org.apache.shiro.authz.Permission Permission} instances.
  *
  * @author Les Hazlewood
  * @since 0.9
@@ -16,16 +16,16 @@
  * might already exist instead of potentially creating one itself.
  *
- * <p>This is mostly implemented by {@link org.apache.ki.authz.Authorizer Authorizer} and
- * {@link org.apache.ki.realm.Realm Realm} implementations since they
+ * <p>This is mostly implemented by {@link org.apache.shiro.authz.Authorizer Authorizer} and
+ * {@link org.apache.shiro.realm.Realm Realm} implementations since they
  * are the ones performing permission checks and need to know how to resolve Strings into

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermission.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermission.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermission.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermission.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
-import org.apache.ki.authz.Permission;
-import org.apache.ki.util.CollectionUtils;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.util.CollectionUtils;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -97,8 +97,8 @@
  * <code>subject.isPermitted( &quot;newsletter:edit:13&quot; )</code>
  * <p/>
  * There is no limit to the number of tokens that can be used, so it is up to your imagination in terms of ways that
  * this could be used in your application.  However, the Ki team likes to standardize some common usages shown
  * above to help people get started and provide consistency in the Ki community.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
@@ -97,8 +97,8 @@
  * <p/>
  * There is no limit to the number of tokens that can be used, so it is up to your imagination in terms of ways that
- * this could be used in your application.  However, the Ki team likes to standardize some common usages shown
- * above to help people get started and provide consistency in the Ki community.
+ * this could be used in your application.  However, the Shiro team likes to standardize some common usages shown
+ * above to help people get started and provide consistency in the Shiro community.
  *
  * @author Jeremy Haile

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermissionResolver.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/WildcardPermissionResolver.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/permission/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,11 +17,11 @@
  * under the License.
  */
 /**
- * Support and default implementations for Ki's {@link org.apache.ki.authz.Permission Permission}
+ * Support and default implementations for Shiro's {@link org.apache.shiro.authz.Permission Permission}
  * interface.
  * <p/>
  * Also note the {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver} interface, as
  * it plays an important part in many of Ki's {@link org.apache.ki.realm.Realm Realm} implementations
  * and AOP support.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
@@ -17,11 +17,11 @@
  * interface.
  * <p/>
- * Also note the {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver} interface, as
- * it plays an important part in many of Ki's {@link org.apache.ki.realm.Realm Realm} implementations
+ * Also note the {@link org.apache.shiro.authz.permission.PermissionResolver PermissionResolver} interface, as
+ * it plays an important part in many of Shiro's {@link org.apache.shiro.realm.Realm Realm} implementations
  * and AOP support.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/Cache.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/Cache.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/Cache.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/Cache.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 import java.util.Set;
 
 /**
  * A Cache efficiently stores temporary objects primarily to improve an application's performance.
  *
  * <p>Ki doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's cache instance (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
  * GigaSpaces, etc, etc), allowing a Ki user to configure any cache mechanism they choose.
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
@@ -16,17 +16,17 @@
  * A Cache efficiently stores temporary objects primarily to improve an application's performance.
  *
- * <p>Ki doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
+ * <p>Shiro doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's cache instance (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
@@ -16,17 +16,17 @@
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's cache instance (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
- * GigaSpaces, etc, etc), allowing a Ki user to configure any cache mechanism they choose.
+ * GigaSpaces, etc, etc), allowing a Shiro user to configure any cache mechanism they choose.
  *
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheException.java Thu Jun 18 03:13:34 2009
@@ -16,19 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
  * Root class of all Ki exceptions related to caching operations.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
  * @since 0.2
  */
-public class CacheException extends KiException {
+public class CacheException extends ShiroException
+{
 
     /**
      * Creates a new <code>CacheException</code>.
@@ -16,19 +16,20 @@
 
 /**
- * Root class of all Ki exceptions related to caching operations.
+ * Root class of all Shiro exceptions related to caching operations.
  *
  * @author Jeremy Haile

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManager.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 /**
  * A CacheManager provides and maintains the lifecycles of {@link Cache Cache} instances.
  *
  * <p>Ki doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's main Manager component (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
  * GigaSpaces, etc, etc), allowing a Ki user to configure any cache mechanism they choose.
  *
  * @author Les Hazlewood
  * @since 0.9
@@ -16,15 +16,15 @@
  * A CacheManager provides and maintains the lifecycles of {@link Cache Cache} instances.
  *
- * <p>Ki doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
+ * <p>Shiro doesn't implement a full Cache mechanism itself, since that is outside the core competency of a
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's main Manager component (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
@@ -16,15 +16,15 @@
  * Security framework.  Instead, this interface provides an abstraction (wrapper) API on top of an underlying
  * cache framework's main Manager component (e.g. JCache, Ehcache, JCS, OSCache, JBossCache, TerraCotta, Coherence,
- * GigaSpaces, etc, etc), allowing a Ki user to configure any cache mechanism they choose.
+ * GigaSpaces, etc, etc), allowing a Shiro user to configure any cache mechanism they choose.
  *
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManagerAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/CacheManagerAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/DefaultCacheManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/DefaultCacheManager.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.ki.util.Destroyable;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.util.Destroyable;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
@@ -30,7 +30,7 @@
  * <p/>
  * This implementation does not offer any enterprise-level features such as cache coherency, optimistic locking,
  * failover or other similar features.  It relies on memory-based {@link java.util.Map Map} caches.  For more
  * enterprise features, consider using an {@link org.apache.ki.cache.ehcache.EhCacheManager EhCacheManager} or other
  * similar implementation that wraps an enterprise-grade Caching solution.
  *
  * @author Les Hazlewood
@@ -30,7 +30,7 @@
  * This implementation does not offer any enterprise-level features such as cache coherency, optimistic locking,
  * failover or other similar features.  It relies on memory-based {@link java.util.Map Map} caches.  For more
- * enterprise features, consider using an {@link org.apache.ki.cache.ehcache.EhCacheManager EhCacheManager} or other
+ * enterprise features, consider using an {@link org.apache.shiro.cache.ehcache.EhCacheManager EhCacheManager} or other
  * similar implementation that wraps an enterprise-grade Caching solution.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCache.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCache.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCache.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCache.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache;
+package org.apache.shiro.cache;
 
 import java.util.Hashtable;
 
 /**
  * An implementation of the Ki {@link Cache} interface that uses a
  * {@link Hashtable} to store cached objects.  This implementation is only suitable for
  * development/testing use as it is prone to a potential memory leak if objects are not explicitly removed
  * from the cache.
@@ -16,12 +16,12 @@
 
 /**
- * An implementation of the Ki {@link Cache} interface that uses a
+ * An implementation of the Shiro {@link Cache} interface that uses a
  * {@link Hashtable} to store cached objects.  This implementation is only suitable for
  * development/testing use as it is prone to a potential memory leak if objects are not explicitly removed

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCacheManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/cache/HashtableCacheManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Base64.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Base64.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.codec;
+package org.apache.shiro.codec;
 
 /**
  * Provides Base64 encoding and decoding as defined by RFC 2045.
@@ -28,7 +28,7 @@
  *
  * <p>This class was borrowed from Apache Commons Codec SVN repository (rev. 618419) with modifications
  * to enable Base64 conversion without a full dependecny on Commons Codec.  We didn't want to reinvent the wheel of
  * great work they've done, but also didn't want to force every Ki user to depend on the commons-codec.jar</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have
  * remained in tact.</p>
@@ -223,7 +223,7 @@
     }
 
     /**
      * Base64 encodes the specified byte array and then encodes it as a String using Ki's preferred character
      * encoding (UTF-8).
      *
      * @param bytes the byte array to Base64 encode.
@@ -28,7 +28,7 @@
  * <p>This class was borrowed from Apache Commons Codec SVN repository (rev. 618419) with modifications
  * to enable Base64 conversion without a full dependecny on Commons Codec.  We didn't want to reinvent the wheel of
- * great work they've done, but also didn't want to force every Ki user to depend on the commons-codec.jar</p>
+ * great work they've done, but also didn't want to force every Shiro user to depend on the commons-codec.jar</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have
@@ -223,7 +223,7 @@
 
     /**
-     * Base64 encodes the specified byte array and then encodes it as a String using Ki's preferred character
+     * Base64 encodes the specified byte array and then encodes it as a String using Shiro's preferred character
      * encoding (UTF-8).
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecSupport.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/CodecSupport.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.codec;
+package org.apache.shiro.codec;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -35,12 +35,12 @@
 public abstract class CodecSupport {
 
     /**
      * Ki's default preferred Character encoding, equal to <b><code>UTF-8</code></b>.
      */
     public static final String PREFERRED_ENCODING = "UTF-8";
 
     /**
      * Converts the specified character array to a byte array using the Ki's preferred encoding (UTF-8).
      * <p/>
      * This is a convenience method equivalent to calling the {@link #toBytes(String,String)} method with a
      * a wrapping String and {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}, i.e.
@@ -72,11 +72,11 @@
     }
 
     /**
      * Converts the specified source argument to a byte array with Ki's
      * {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
      * @param source the string to convert to a byte array.
      * @return the bytes representing the specified string under Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      */
     public static byte[] toBytes(String source) {
         return toBytes(source, PREFERRED_ENCODING);
@@ -102,7 +102,7 @@
     }
 
     /**
      * Converts the specified byte array to a string using Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
      * @param bytes the byte array to turn into a String.
      * @return the specified byte array as an encoded String ({@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}).
@@ -129,7 +129,7 @@
     }
 
     /**
      * Returns the specified byte array as a character array using Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
      * @param bytes the byte array to convert to a char array
      * @return the specified byte array encoded as a character array ({@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}).
@@ -35,12 +35,12 @@
 
     /**
-     * Ki's default preferred Character encoding, equal to <b><code>UTF-8</code></b>.
+     * Shiro's default preferred Character encoding, equal to <b><code>UTF-8</code></b>.
      */
     public static final String PREFERRED_ENCODING = "UTF-8";
@@ -35,12 +35,12 @@
 
     /**
-     * Converts the specified character array to a byte array using the Ki's preferred encoding (UTF-8).
+     * Converts the specified character array to a byte array using the Shiro's preferred encoding (UTF-8).
      * <p/>
      * This is a convenience method equivalent to calling the {@link #toBytes(String,String)} method with a
@@ -72,11 +72,11 @@
 
     /**
-     * Converts the specified source argument to a byte array with Ki's
+     * Converts the specified source argument to a byte array with Shiro's
      * {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
@@ -72,11 +72,11 @@
      *
      * @param source the string to convert to a byte array.
-     * @return the bytes representing the specified string under Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
+     * @return the bytes representing the specified string under Shiro's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      */
     public static byte[] toBytes(String source) {
@@ -102,7 +102,7 @@
 
     /**
-     * Converts the specified byte array to a string using Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
+     * Converts the specified byte array to a string using Shiro's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
      * @param bytes the byte array to turn into a String.
@@ -129,7 +129,7 @@
 
     /**
-     * Returns the specified byte array as a character array using Ki's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
+     * Returns the specified byte array as a character array using Shiro's {@link CodecSupport#PREFERRED_ENCODING PREFERRED_ENCODING}.
      *
      * @param bytes the byte array to convert to a char array

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Hex.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Hex.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Hex.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/Hex.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.codec;
+package org.apache.shiro.codec;
 
 /**
  * Hex encoder and decoder.
  *
  * <p>This class was borrowed from Apache Commons Codec SVN repository (rev. 560660 ) with modifications
  * to enable Hex conversion without a full dependency on Commons Codec.  We didn't want to reinvent the wheel of
  * great work they've done, but also didn't want to force every Ki user to depend on the commons-codec.jar</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have
  * remained in tact.</p>
@@ -16,14 +16,14 @@
  * <p>This class was borrowed from Apache Commons Codec SVN repository (rev. 560660 ) with modifications
  * to enable Hex conversion without a full dependency on Commons Codec.  We didn't want to reinvent the wheel of
- * great work they've done, but also didn't want to force every Ki user to depend on the commons-codec.jar</p>
+ * great work they've done, but also didn't want to force every Shiro user to depend on the commons-codec.jar</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/codec/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 /**
  * Components for encoding and decoding of data across multiple formats, especially useful in Ki's
  * cryptography and web functionality.
  */
-package org.apache.ki.codec;
+package org.apache.shiro.codec;
@@ -17,7 +17,7 @@
  */
 /**
- * Components for encoding and decoding of data across multiple formats, especially useful in Ki's
+ * Components for encoding and decoding of data across multiple formats, especially useful in Shiro's
  * cryptography and web functionality.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/Configuration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/Configuration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/Configuration.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/Configuration.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
-import org.apache.ki.mgt.SecurityManagerFactory;
+import org.apache.shiro.mgt.SecurityManagerFactory;
 
 
 /**
  * A <code>Configuration</code> is responsible for 'wiring' together all the Ki components for an
  * application, such as the {@link org.apache.ki.mgt.SecurityManager SecurityManager}, and any of its
  * dependencies.
  * <p/>
  * Once the SecurityManager is built by the <code>Configuration</code> it is then consulted for all security
@@ -16,14 +16,14 @@
 
 /**
- * A <code>Configuration</code> is responsible for 'wiring' together all the Ki components for an
- * application, such as the {@link org.apache.ki.mgt.SecurityManager SecurityManager}, and any of its
+ * A <code>Configuration</code> is responsible for 'wiring' together all the Shiro components for an
+ * application, such as the {@link org.apache.shiro.mgt.SecurityManager SecurityManager}, and any of its
  * dependencies.
  * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ConfigurationException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ConfigurationException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ConfigurationException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ConfigurationException.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
+
+import org.apache.shiro.ShiroException;
 
-import org.apache.ki.KiException;
 
 /**
  * Root exception indicating there was a problem parsing or processing the Ki configuration.
  *
  * @author Les Hazlewood
  * @since 0.9
  */
-public class ConfigurationException extends KiException {
+public class ConfigurationException extends ShiroException
+{
 
     /**
      * Creates a new ConfigurationException.
@@ -16,17 +16,19 @@
 
 /**
- * Root exception indicating there was a problem parsing or processing the Ki configuration.
+ * Root exception indicating there was a problem parsing or processing the Shiro configuration.
  *
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/IniConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/IniConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ReflectionBuilder.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ReflectionBuilder.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 import java.beans.PropertyDescriptor;
 import java.util.HashMap;
@@ -28,13 +28,13 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.util.ClassUtils;
-import org.apache.ki.util.Nameable;
+import org.apache.shiro.util.ClassUtils;
+import org.apache.shiro.util.Nameable;
 
 
 /**
  * Object builder that uses reflection and Apache Commons BeanUtils to build objects given a
  * map of "property values".  Typically these come from the Ki INI configuration and are used
  * to construct or modify the SecurityManager, its dependencies, and web-based security filters.
  *
  * @author Les Hazlewood
@@ -50,7 +50,7 @@
 
     private static final String OBJECT_REFERENCE_BEGIN_TOKEN = "$";
     private static final String ESCAPED_OBJECT_REFERENCE_BEGIN_TOKEN = "\\$";
-    private static final String GLOBAL_PROPERTY_PREFIX = "ki";
+    private static final String GLOBAL_PROPERTY_PREFIX = "shiro";
 
 
     protected Map objects;
@@ -28,13 +28,13 @@
 /**
  * Object builder that uses reflection and Apache Commons BeanUtils to build objects given a
- * map of "property values".  Typically these come from the Ki INI configuration and are used
+ * map of "property values".  Typically these come from the Shiro INI configuration and are used
  * to construct or modify the SecurityManager, its dependencies, and web-based security filters.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ResourceConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/ResourceConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/config/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,6 +17,6 @@
  * under the License.
  */
 /**
  * Components that support configuring Ki in any application.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
@@ -17,6 +17,6 @@
  */
 /**
- * Components that support configuring Ki in any application.
+ * Components that support configuring Shiro in any application.
  */